DynamicField

Struct DynamicField 

#[non_exhaustive]
pub struct DynamicField { pub kind: Option<i32>, pub parent: Option<ObjectId>, pub field_id: Option<ObjectId>, pub field_object: Option<Object>, pub name: Option<BcsData>, pub value: Option<BcsData>, pub value_type: Option<String>, pub child_id: Option<ObjectId>, pub child_object: Option<Object>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
kind: Option<i32>parent: Option<ObjectId>

ObjectId of this dynamic field’s parent.

field_id: Option<ObjectId>

ObjectId of this dynamic field.

field_object: Option<Object>

The field object itself

name: Option<BcsData>

The dynamic field’s “name”

value: Option<BcsData>

The dynamic field’s “value”.

For regular dynamic fields this contains the BCS-encoded value whose type is given by value_type. For dynamic object fields this contains the BCS-encoded ObjectID of the child object; use child_object to access the full object.

value_type: Option<String>

The type of the dynamic field “value”.

For regular dynamic fields this is the Move type of the value stored in the value field. For dynamic object fields this is the Move type of the child object itself (e.g. 0x2::coin::Coin<0x2::iota::IOTA>), not 0x2::object::ID — clients should use child_object rather than BCS-decoding value with this type.

child_id: Option<ObjectId>

The ObjectId of the child object when a child is a dynamic object field.

The presence or absence of this field can be used to determine if a child is a dynamic field or a dynamic child object

child_object: Option<Object>

The object itself when a child is a dynamic object field.

Implementations

Source

impl DynamicField

Source

impl DynamicField

Source

impl DynamicField

pub fn with_kind(self, field: DynamicFieldKind) -> Self

Sets kind with the provided value.

pub fn with_parent<T: Into<ObjectId>>(self, field: T) -> Self

Sets parent with the provided value.

pub fn with_field_id<T: Into<ObjectId>>(self, field: T) -> Self

Sets field_id with the provided value.

pub fn with_field_object<T: Into<Object>>(self, field: T) -> Self

Sets field_object with the provided value.

pub fn with_name<T: Into<BcsData>>(self, field: T) -> Self

Sets name with the provided value.

pub fn with_value<T: Into<BcsData>>(self, field: T) -> Self

Sets value with the provided value.

pub fn with_value_type<T: Into<String>>(self, field: T) -> Self

Sets value_type with the provided value.

pub fn with_child_id<T: Into<ObjectId>>(self, field: T) -> Self

Sets child_id with the provided value.

pub fn with_child_object<T: Into<Object>>(self, field: T) -> Self

Sets child_object with the provided value.

Source

impl DynamicField

pub fn kind(&self) -> DynamicFieldKind

Returns the enum value of kind, or the default if the field is unset or set to an invalid enum value.

pub fn set_kind(&mut self, value: DynamicFieldKind)

Sets kind to the provided enum value.

pub fn value_type(&self) -> &str

Returns the value of value_type, or the default value if value_type is unset.